**Change keyboard layout in console (Debian)**

    dpkg-reconfigure keyboard-configuration
    # apply changes (may not be necessary)
    systemctl restart keyboard-setup

Source: <https://wiki.debian.org/Keyboard>

- - -

**Check/Open SSL connection (command line)**

    echo | openssl s_client -connect $HOST -port $PORT -servername $SNI

- - -

**Resize an ext partition in LVM**

    lvresize -L+20G vg/lv
    resize2fs /dev/mapper/vg-lv

- - -

**Useful `grep` options**

    -l  --files-with-matches
    -o  --only-matching
    -H  --with-filename

- - -

**Handling NUL-separated strings**

* `grep`: `-z` for input, `-Z` for output
* `find`: `-print0` for output
* `sort`: `-z` for both input and output
* `awk`: `BEGIN { RS="\0" }` for input, `BEGIN { ORS="\0" }` for output

- - -

**Start `tmux` with programs in windows**

    #!/bin/bash

    SESS=$$

    CMD[1]='top'
    CMD[2]='watch -n 1 cat /proc/mdstat'
    CMD[3]='while sleep 5; do date | tee -a ps; ps aux | tee -a ps; done'
        
    tmux new-session -s $SESS -n window0 -d bash

    for N in $(seq ${#CMD[*]}); do
        echo "Running command $N: ${CMD[$N]}"
        tmux new-window -t $SESS:$N -n windows$N "${CMD[$N]}"
    done
    echo "Done. press enter to attach tmux..."
    read

    tmux select-window -t $SESS:0
    tmux attach

- - -

**Window reorganization**

* `vim`: `C-W H/J/K/L`
* `tmux`: `C-B space`

- - -

**Online markdown editor**

<https://stackedit.io/editor>

- - -

**Copy from buffer in `tmux`**

<https://awhan.wordpress.com/2010/06/20/copy-paste-in-tmux/>

- - -

**`find` excluding some directories**

Find and print all files in `/` except those in directory `.git`:

    find / -type f \( -path './.git/*' -prune -o -print \)

Find and print all files in `cwd` except those in directory `.git` and those matching filename `.meta.*`:

    find . -type f \( \( -path './.git/*' -o -name '.meta.*' \) -prune -o -print \)

- - -

**JSON pretty-printing one-liner**

For an existing file:

    perl -MJSON::PP -MFile::Slurp -e '$x = JSON::PP->new->utf8->pretty; print $x->encode($x->decode(read_file($ARGV[0])));' file.json

For an input from another command:

    command | perl -MJSON::PP -e '$x = JSON::PP->new->ascii->pretty; print $x->encode($x->decode(<>));'

- - -

**Wireshark for remote machine**

    ssh root@$REMOTE tcpdump -U -i $IFACE $PCAPFILTER -w /dev/stdout | wireshark -k -i - -d $DISPLAYFILTER
    ssh root@$REMOTE tcpdump -U -i $IFACE $PCAPFILTER -w /dev/stdout | tshark -x -r - -O $VERBOSEPROTOS $CAPTUREFILTER

Examples:

    ssh root@ares tcpdump -U -i vlan2 host lj2b -w /dev/stdout | wireshark -k -i - -d 'icmp'
    ssh root@ares tcpdump -U -i vlan48 host aisa -w /dev/stdout | tshark -x -r - -O dns 'udp.port == 53'

- - -

**Wireshark with cyclic pcap save buffers**

    tcpdump -i vlan2 icmp6 -G 86400 -w /tmp/capture-%w.pcap

| -G    | -w | description     |
| ----- | -- | --------------- |
| 86400 | %w | 7 saves daily   |
| 3600  | %d | 24 saves hourly |

- - -

**X11 forwarding through `ssh` after running `su`**

    client$ ssh -X user1@host2
    user1@host$ xauth list $DISPLAY
    user1@host$ su - user2
    user2@host$ xauth add <relevant_line_from_xauth_list>

Source: <https://debian-administration.org/article/494/Getting_X11_forwarding_through_ssh_working_after_running_su>

- - -

**Timestamping**

    command | awk '{ print strftime("[%Y-%m-%d %H:%M:%S]"), $0 }'

Source: <https://unix.stackexchange.com/questions/26728/prepending-a-timestamp-to-each-line-of-output-from-a-command>

- - -

**pstree**

    pstree -aclnp

* `-a`: Show command line arguments
* `-c`: Disable compaction of identical subtrees
* `-l`: Display long lines
* `-n`: Sort processes with the same ancestor by PID instead of by name
* `-p`: Show PIDs

- - -

**Other cheat sheets**

* Markdown: <http://packetlife.net/media/library/16/Markdown.pdf>
* Unix Toolbox: <http://cb.vu/unixtoolbox.xhtml>
